\name{readMAPPER}
\alias{readMAPPER}
\title{Retrieve a set of predicted transcription factor binding sites from the MAPPER database}
\description{The MAPPER RPC interface allows you to retrieve a set of predicted transcription 
factor binding sites from the MAPPER database through a simple HTTP request. This package
provides a function to retrieve predicted TFBS from R.
}
\usage{
 readMAPPER(stub = paste(urlpath, "db-rpc?", sep = ""), ...)
}
\arguments{
  \item{stub}{ stub -- a string giving the URL handle up to the db-rpc selector (optional)}
  \item{\dots}{ \dots -- all the query parameters (see Details).}
}
\details{
Currently (9/10) the RPC interface to MAPPER defines
the following parameters.  You can use any of these
as keywords (with bindings supplied using "=", e.g.,
\code{gene="CRP"}) to the \code{readMAPPER} function.

gene - you can use either NCBI GeneID or mRNA accession number; gene 
names should work too, but this is not recommended because there often 
are multiple forms of the same gene. [required, unless 'list' is specified]

models - a comma-separated list of model names (to restrict the output 
to these models only) [required, unless 'list' is specified]

score - the score threshold (0 by default)

perc - the percentile (one of 50, 80, 85, 90, 95). Only hits with scores above 
the desired percentile for each model are returned.

eval - the E-value threshold (25 by default)

pbases - how many basepairs to look at (default: 2000). See pstart.

pstart - what pbases is relative to (either T for transcript start or C 
for coding sequence start - remember that in the db we have hits for the 
region from 10,000 bp upstream of transcript start to 50bp after coding 
sequence start)

sort - how to sort the results: either M (by model accession), N (factor 
name), E (by E-value), S (by score), P (by position, the default)

org - two letter organism code

list - returns a list of all TF names with the corresponding model
   accession numbers.  All other parameters are ignored.

If you issue \code{rmapperHelp()}, you will get a help page in text.
}
\value{
An instance of the mapperHits class.
}
\references{ \url{http://genome.ufl.edu/mapper/} }

\author{Vince Carey <stvjc@channing.harvard.edu>}

\examples{
 # Run an example retrieving data from the MAPPER RPC interface for gene ID = NM_009696
 mh = readMAPPER(gene="NM_009696", perc="95", models="M00027")
 # Display the mapperHits object returned by readMAPPER
 mh
 # Display the exact query that was issued to the MAPPER RPC interface
 query(mh)
 # Display the details of hits from the query 
 hits(mh)
}

\seealso{
	\code{\link{mapperHits-class} \link{query} \link{hits}}
}

\keyword{models}
